.. image:: _static/logo.png
   :align: center
   :width: 80%
   :class: dark-light


BlazeFL Documentation
=====================

**BlazeFL** is a blazing-fast and lightweight simulation framework for Federated Learning.

.. toctree::
   :maxdepth: 1

   install
   overview
   benchmark
   example
   reference
   contribute
